==> sumus-7.0.3-sources.jar: io/intino/sumus/graph/Cluster.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Cluster extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.konos.alexandria.activity.model.Catalog catalog;
	protected java.lang.String label;
	protected java.lang.String username;
	protected java.util.List<io.intino.sumus.graph.Cluster.Group> groupList = new java.util.ArrayList<>();

	public Cluster(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.konos.alexandria.activity.model.Catalog catalog() {
		return catalog;
	}

	public java.lang.String label() {
		return label;
	}

	public java.lang.String username() {
		return username;
	}

	public Cluster catalog(io.intino.konos.alexandria.activity.model.Catalog value) {
		this.catalog = value;
		return (Cluster) this;
	}

	public Cluster label(java.lang.String value) {
		this.label = value;
		return (Cluster) this;
	}

	public Cluster username(java.lang.String value) {
		this.username = value;
		return (Cluster) this;
	}

	public java.util.List<io.intino.sumus.graph.Cluster.Group> groupList() {
		return java.util.Collections.unmodifiableList(groupList);
	}

	public io.intino.sumus.graph.Cluster.Group group(int index) {
		return groupList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Cluster.Group> groupList(java.util.function.Predicate<io.intino.sumus.graph.Cluster.Group> predicate) {
		return groupList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(groupList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("catalog", new java.util.ArrayList(java.util.Collections.singletonList(this.catalog)));
		map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
		map.put("username", new java.util.ArrayList(java.util.Collections.singletonList(this.username)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Cluster$Group")) this.groupList.add(node.as(io.intino.sumus.graph.Cluster.Group.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Cluster$Group")) this.groupList.remove(node.as(io.intino.sumus.graph.Cluster.Group.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("catalog")) this.catalog = io.intino.tara.magritte.loaders.ObjectLoader.load(values,io.intino.konos.alexandria.activity.model.Catalog.class, this).get(0);
		else if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("username")) this.username = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("catalog")) this.catalog = (io.intino.konos.alexandria.activity.model.Catalog) values.get(0);
		else if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
		else if (name.equalsIgnoreCase("username")) this.username = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Cluster.Group group(java.lang.String label) {
		    io.intino.sumus.graph.Cluster.Group newElement = core$().graph().concept(io.intino.sumus.graph.Cluster.Group.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Cluster.Group.class);
			newElement.core$().set(newElement, "label", java.util.Collections.singletonList(label));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void group(java.util.function.Predicate<io.intino.sumus.graph.Cluster.Group> filter) {
			new java.util.ArrayList<>(groupList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Group extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected java.lang.String label;
		protected java.util.List<io.intino.sumus.graph.Entity> entities = new java.util.ArrayList<>();

		public Group(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public java.lang.String label() {
			return label;
		}

		public java.util.List<io.intino.sumus.graph.Entity> entities() {
			return entities;
		}

		public io.intino.sumus.graph.Entity entities(int index) {
			return entities.get(index);
		}

		public java.util.List<io.intino.sumus.graph.Entity> entities(java.util.function.Predicate<io.intino.sumus.graph.Entity> predicate) {
			return entities().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public Group label(java.lang.String value) {
			this.label = value;
			return (Group) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
			map.put("entities", this.entities);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("entities")) this.entities = io.intino.tara.magritte.loaders.NodeLoader.load(values,  io.intino.sumus.graph.Entity.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("entities")) this.entities = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.tara.magritte.Layer) s).core$().id()).as(io.intino.sumus.graph.Entity.class)).collect(java.util.stream.Collectors.toList());
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/Cluster.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Cluster extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.konos.alexandria.ui.model.Catalog catalog;
	protected java.lang.String label;
	protected java.lang.String username;
	protected java.util.List<io.intino.sumus.graph.Cluster.Group> groupList = new java.util.ArrayList<>();

	public Cluster(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.konos.alexandria.ui.model.Catalog catalog() {
		return catalog;
	}

	public java.lang.String label() {
		return label;
	}

	public java.lang.String username() {
		return username;
	}

	public Cluster catalog(io.intino.konos.alexandria.ui.model.Catalog value) {
		this.catalog = value;
		return (Cluster) this;
	}

	public Cluster label(java.lang.String value) {
		this.label = value;
		return (Cluster) this;
	}

	public Cluster username(java.lang.String value) {
		this.username = value;
		return (Cluster) this;
	}

	public java.util.List<io.intino.sumus.graph.Cluster.Group> groupList() {
		return java.util.Collections.unmodifiableList(groupList);
	}

	public io.intino.sumus.graph.Cluster.Group group(int index) {
		return groupList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Cluster.Group> groupList(java.util.function.Predicate<io.intino.sumus.graph.Cluster.Group> predicate) {
		return groupList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(groupList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("catalog", new java.util.ArrayList(java.util.Collections.singletonList(this.catalog)));
		map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
		map.put("username", new java.util.ArrayList(java.util.Collections.singletonList(this.username)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Cluster$Group")) this.groupList.add(node.as(io.intino.sumus.graph.Cluster.Group.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Cluster$Group")) this.groupList.remove(node.as(io.intino.sumus.graph.Cluster.Group.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("catalog")) this.catalog = io.intino.tara.magritte.loaders.ObjectLoader.load(values,io.intino.konos.alexandria.ui.model.Catalog.class, this).get(0);
		else if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("username")) this.username = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("catalog")) this.catalog = (io.intino.konos.alexandria.ui.model.Catalog) values.get(0);
		else if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
		else if (name.equalsIgnoreCase("username")) this.username = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Cluster.Group group(java.lang.String label) {
		    io.intino.sumus.graph.Cluster.Group newElement = core$().graph().concept(io.intino.sumus.graph.Cluster.Group.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Cluster.Group.class);
			newElement.core$().set(newElement, "label", java.util.Collections.singletonList(label));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void group(java.util.function.Predicate<io.intino.sumus.graph.Cluster.Group> filter) {
			new java.util.ArrayList<>(groupList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Group extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected java.lang.String label;
		protected java.util.List<io.intino.sumus.graph.Entity> entities = new java.util.ArrayList<>();

		public Group(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public java.lang.String label() {
			return label;
		}

		public java.util.List<io.intino.sumus.graph.Entity> entities() {
			return entities;
		}

		public io.intino.sumus.graph.Entity entities(int index) {
			return entities.get(index);
		}

		public java.util.List<io.intino.sumus.graph.Entity> entities(java.util.function.Predicate<io.intino.sumus.graph.Entity> predicate) {
			return entities().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public Group label(java.lang.String value) {
			this.label = value;
			return (Group) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
			map.put("entities", this.entities);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("entities")) this.entities = io.intino.tara.magritte.loaders.NodeLoader.load(values,  io.intino.sumus.graph.Entity.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("entities")) this.entities = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.tara.magritte.Layer) s).core$().id()).as(io.intino.sumus.graph.Entity.class)).collect(java.util.stream.Collectors.toList());
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
